# io

File input and output functionalities.

| File    | Description |
| :-----: | :---------: |
| cube.py | CUBE file handling |
| gth.py  | GTH file handling |
| json.py | JSON file handling |
| pdb.py  | PDB file handling |
| xyz.py  | XYZ file handling |
